@@ -14,6 +14,10 @@ struct GpuSolidColorExample
   halp_meta(category, "Visuals")
   halp_meta(c_name, "solid_color")
   halp_meta(author, "Jean-Michaël Celerier")
+  halp_meta(
+      manual_url,
+      "https://ossia.io/score-docs/processes/"
+      "graphics-utilities.html#solid-color")
   halp_meta(description, "Render a solid color")
 
   struct layout
