@@ -1,8 +1,15 @@
 #pragma once
 
-#if defined(__GNUC__)
+#include <version>
+#if __cpp_constexpr >= 202211L
+#define AVND_STATIC_CONSTEXPR static constexpr
+#else
+#define AVND_STATIC_CONSTEXPR constexpr
+#endif
+
+#if defined(__clang__)
 #define AVND_INLINE inline __attribute__((always_inline))
-#elif defined(__clang__)
+#elif defined(__GNUC__)
 #define AVND_INLINE inline __attribute__((always_inline))
 #elif defined(_MSC_VER)
 #define AVND_INLINE inline __forceinline
@@ -10,8 +17,12 @@
 #define AVND_INLINE inline
 #endif
 
-#if defined(__clang__)
+#if defined __has_attribute
+#if __has_attribute(flatten)
 #define AVND_INLINE_FLATTEN AVND_INLINE __attribute__((flatten))
-#else
+#endif
+#endif
+
+#if !defined(AVND_INLINE_FLATTEN)
 #define AVND_INLINE_FLATTEN AVND_INLINE
 #endif
