@@ -1,11 +1,17 @@
-#include <boost/test/included/unit_test.hpp>
+//
+// Copyright (c) 2023-2024 Ivica Siladic, Bruno Iljazovic, Korina Simicevic
+//
+// Distributed under the Boost Software License, Version 1.0.
+// (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)
+//
 
-#include <test_common/protocol_logging.hpp>
+#define BOOST_TEST_MODULE async_mqtt5_tests
+
+#include <boost/test/included/unit_test.hpp>
 
 boost::unit_test::test_suite* init_tests(
 	int /*argc*/, char* /*argv*/[]
 ) {
-	async_mqtt5::test::logging_enabled() = false;
 	return nullptr;
 }
 
