@@ -16,7 +16,9 @@
 #include <boost/asio/steady_timer.hpp>
 #include <boost/asio/ip/tcp.hpp>
 
+#include <async_mqtt5/logger_traits.hpp>
 #include <async_mqtt5/types.hpp>
+#include <async_mqtt5/detail/log_invoke.hpp>
 #include <async_mqtt5/detail/internal_types.hpp>
 #include <async_mqtt5/impl/connect_op.hpp>
 
@@ -64,9 +66,10 @@ void run_unit_test(
 		std::move(h)(ec);
 	};
 
-	detail::connect_op<test::test_stream>(
-		stream, std::move(handler), mqtt_ctx
-	).perform(eps, ap);
+	detail::log_invoke<noop_logger> d;
+	detail::connect_op<test::test_stream, noop_logger>(
+		stream, mqtt_ctx, d, std::move(handler)
+	).perform(*std::begin(eps), std::move(ap));
 
 	ioc.run_for(1s);
 	BOOST_TEST(handlers_called == expected_handlers_called);
