@@ -33,9 +33,7 @@
 #include "shape.hpp"
 
 #include <tuple>
-#ifdef KFR_STD_COMPLEX
 #include <complex>
-#endif
 
 CMT_PRAGMA_GNU(GCC diagnostic push)
 CMT_PRAGMA_GNU(GCC diagnostic ignored "-Wshadow")
@@ -44,22 +42,10 @@ CMT_PRAGMA_GNU(GCC diagnostic ignored "-Wparentheses")
 namespace kfr
 {
 
-#ifdef KFR_STD_COMPLEX
-
+#ifndef KFR_CUSTOM_COMPLEX
 template <typename T>
 using complex = std::complex<T>;
-
-#else
-#ifndef KFR_CUSTOM_COMPLEX
-
-template <typename>
-struct complex;
 #endif
-#endif
-
-struct accepts_any
-{
-};
 
 template <typename T, typename V = void>
 struct expression_traits;
@@ -118,7 +104,7 @@ struct expression_traits<T, std::void_t<decltype(T::random_access), decltype(T::
 
 struct expression_traits_defaults
 {
-    // using value_type = accepts_any;
+    // using value_type = /* ... */;
     // constexpr static size_t dims = 0;
     // constexpr static shape<dims> get_shape(const T&);
     // constexpr static shape<dims> get_shape();
@@ -191,7 +177,7 @@ constexpr inline bool is_input_output_expression<E, enable_if_input_output_expre
     KFR_ENABLE_IF(is_input_output_expression<E1>&& is_input_expression<E2>)
 
 template <typename T>
-constexpr inline bool is_expr_element = std::is_same_v<std::remove_cv_t<T>, T>&& is_vec_element<T>;
+constexpr inline bool is_expr_element = std::is_same_v<std::remove_cv_t<T>, T> && is_vec_element<T>;
 
 template <typename E>
 constexpr inline bool is_infinite = expression_traits<E>::get_shape().has_infinity();
@@ -284,6 +270,12 @@ KFR_INTRINSIC void set_elements(T& self, const shape<0>& index, const axis_param
     self = val.front();
 }
 
+template <typename T>
+constexpr inline bool is_arg = is_numeric_or_bool<std::decay_t<T>>;
+
+template <typename T>
+using arg = std::conditional_t<is_arg<T>, std::decay_t<T>, T>;
+
 template <typename... Args>
 struct expression_with_arguments
 {
@@ -340,7 +332,7 @@ struct expression_with_arguments
         return fold_idx_impl(std::forward<Fn>(fn), csizeseq<count>);
     }
 
-    KFR_INTRINSIC expression_with_arguments(Args&&... args) : args{ std::forward<Args>(args)... }
+    KFR_INTRINSIC expression_with_arguments(arg<Args&&>... args) : args{ std::forward<Args>(args)... }
     {
         cforeach(csizeseq<count>,
                  [&](auto idx_) CMT_INLINE_LAMBDA
@@ -474,18 +466,21 @@ struct expression_function : expression_with_arguments<Args...>, expression_trai
 #else
     constexpr static shape<dims> get_shape(const expression_function& self)
     {
-        return self.fold([&](auto&&... args) CMT_INLINE_LAMBDA constexpr->auto {
-            return internal_generic::common_shape<true>(
-                expression_traits<decltype(args)>::get_shape(args)...);
-        });
+        return self.fold(
+            [&](auto&&... args) CMT_INLINE_LAMBDA constexpr -> auto {
+                return internal_generic::common_shape<true>(
+                    expression_traits<decltype(args)>::get_shape(args)...);
+            });
     }
     constexpr static shape<dims> get_shape()
     {
-        return expression_function::fold_idx([&](auto... args) CMT_INLINE_LAMBDA constexpr->auto {
-            return internal_generic::common_shape(
-                expression_traits<
-                    typename expression_function::template nth<val_of(decltype(args)())>>::get_shape()...);
-        });
+        return expression_function::fold_idx(
+            [&](auto... args) CMT_INLINE_LAMBDA constexpr -> auto
+            {
+                return internal_generic::common_shape(
+                    expression_traits<typename expression_function::template nth<val_of(decltype(args)())>>::
+                        get_shape()...);
+            });
     }
 #endif
 
@@ -497,11 +492,11 @@ struct expression_function : expression_with_arguments<Args...>, expression_trai
         : expression_with_arguments<Args...>{ std::move(args) }, fn(std::forward<Fn>(fn))
     {
     }
-    KFR_MEM_INTRINSIC expression_function(Fn&& fn, Args&&... args)
+    KFR_MEM_INTRINSIC expression_function(Fn&& fn, arg<Args&&>... args)
         : expression_with_arguments<Args...>{ std::forward<Args>(args)... }, fn(std::forward<Fn>(fn))
     {
     }
-    KFR_MEM_INTRINSIC expression_function(Args&&... args)
+    KFR_MEM_INTRINSIC expression_function(arg<Args&&>... args)
         : expression_with_arguments<Args...>{ std::forward<Args>(args)... }, fn{}
     {
     }
@@ -523,6 +518,9 @@ expression_function(expression_with_arguments<Args...>&& args, Fn&& fn) -> expre
 template <typename... Args, typename Fn>
 expression_function(expression_with_arguments<Args...>& args, Fn&& fn) -> expression_function<Fn, Args...>;
 
+template <typename Fn, typename... Args>
+using expression_make_function = expression_function<Fn, arg<Args>...>;
+
 namespace internal
 {
 
@@ -601,10 +599,8 @@ template <typename Fn, typename... Args, index_t Axis, size_t N, index_t Dims,
 KFR_INTRINSIC vec<T, N> get_elements(const expression_function<Fn, Args...>& self, const shape<Dims>& index,
                                      const axis_params<Axis, N>& sh)
 {
-    return self.fold_idx(
-        [&](auto... idx) CMT_INLINE_LAMBDA -> vec<T, N> {
-            return self.fn(internal::get_arg<Tr::dims>(self, index, sh, idx)...);
-        });
+    return self.fold_idx([&](auto... idx) CMT_INLINE_LAMBDA -> vec<T, N>
+                         { return self.fn(internal::get_arg<Tr::dims>(self, index, sh, idx)...); });
 }
 
 template <typename Out, typename In, index_t OutAxis, size_t w, size_t gw, typename Tin, index_t outdims,
@@ -759,7 +755,7 @@ static auto process(Out&& out, In&& in, shape<outdims> start = shape<outdims>(0)
         in_size = inshape[in_axis];
 
     begin_pass(out, start, stop);
-    begin_pass(in, inshape.adapt(start), inshape.adapt(stop));
+    begin_pass(in, inshape.adapt(start), inshape.adapt(stop, ctrue));
 
     shape<outdims> outidx;
     if constexpr (outdims == 1)
@@ -830,7 +826,7 @@ static auto process(Out&& out, In&& in, shape<outdims> start = shape<outdims>(0)
             outidx[out_axis] = stop[out_axis] - 1;
         } while (internal_generic::increment_indices(outidx, start, stop));
     }
-    end_pass(in, inshape.adapt(start), inshape.adapt(stop));
+    end_pass(in, inshape.adapt(start), inshape.adapt(stop, ctrue));
     end_pass(out, start, stop);
     return stop;
 }
