@@ -38,6 +38,7 @@
 #include "expression.hpp"
 #include "memory.hpp"
 #include "shape.hpp"
+#include "transpose.hpp"
 
 CMT_PRAGMA_MSVC(warning(push))
 CMT_PRAGMA_MSVC(warning(disable : 4324))
@@ -352,12 +353,12 @@ public:
     tensor(const tensor&& other) : tensor(static_cast<const tensor&>(other)) {}
 #else
     tensor(const tensor&) = default;
-    tensor(tensor&&)      = default;
+    tensor(tensor&&) = default;
     tensor(tensor& other) : tensor(const_cast<const tensor&>(other)) {}
     tensor(const tensor&& other) : tensor(static_cast<const tensor&>(other)) {}
 #endif
 
-#if defined(CMT_COMPILER_IS_MSVC)
+#if defined(CMT_COMPILER_IS_MSVC) || true
     tensor& operator=(const tensor& src) &
     {
         this->~tensor();
@@ -372,7 +373,7 @@ public:
     }
 #else
     tensor& operator=(const tensor& src) & = default;
-    tensor& operator=(tensor&& src) & = default;
+    tensor& operator=(tensor&& src) &      = default;
 #endif
 
     KFR_MEM_INTRINSIC const tensor& operator=(const tensor& src) const&
@@ -509,9 +510,26 @@ public:
 
     using tensor_subscript<T, tensor<T, NDims>, std::make_integer_sequence<index_t, NDims>>::operator();
 
+    KFR_MEM_INTRINSIC tensor transpose() const
+    {
+        if constexpr (dims <= 1)
+        {
+            return *this;
+        }
+        else
+        {
+            return tensor<T, dims>{
+                m_data,
+                m_shape.transpose(),
+                m_strides.transpose(),
+                m_finalizer,
+            };
+        }
+    }
+
     template <index_t dims>
     KFR_MEM_INTRINSIC tensor<T, dims> reshape_may_copy(const kfr::shape<dims>& new_shape,
-                                                       bool allow_copy = false) const
+                                                       bool allow_copy = true) const
     {
         if (size_of_shape(new_shape) != m_size)
         {
@@ -550,9 +568,9 @@ public:
         return reshape_may_copy(new_shape, false);
     }
 
-    KFR_MEM_INTRINSIC tensor<T, 1> flatten() const { return reshape(kfr::shape<1>{ m_size }, false); }
+    KFR_MEM_INTRINSIC tensor<T, 1> flatten() const { return reshape(kfr::shape<1>{ m_size }); }
 
-    KFR_MEM_INTRINSIC tensor<T, 1> flatten_may_copy(bool allow_copy = false) const
+    KFR_MEM_INTRINSIC tensor<T, 1> flatten_may_copy(bool allow_copy = true) const
     {
         return reshape_may_copy(kfr::shape<1>{ m_size }, allow_copy);
     }
@@ -862,6 +880,12 @@ private:
     memory_finalizer m_finalizer;
 };
 
+template <typename T>
+struct tensor<T, dynamic_shape>
+{
+    // Not implemented yet
+};
+
 // template <typename T>
 // struct tensor<T, 0>
 // {
@@ -966,6 +990,16 @@ struct representation<kfr::tensor<T, dims>>
     static std::string get(const kfr::tensor<T, dims>& value) { return value.to_string(); }
 };
 
+template <char t, int width, int prec, typename T, kfr::index_t dims>
+struct representation<fmt_t<kfr::tensor<T, dims>, t, width, prec>>
+{
+    using type = std::string;
+    static std::string get(const fmt_t<kfr::tensor<T, dims>, t, width, prec>& value)
+    {
+        return array_to_string<fmt_t<T, t, width, prec>>(value.value.size(), value.value.data());
+    }
+};
+
 } // namespace cometa
 
 CMT_PRAGMA_MSVC(warning(pop))
