@@ -2,7 +2,7 @@
 
 #include <libremidi/backends/linux/dylib_loader.hpp>
 
-#include <alsa/asoundlib.h>
+#include <alsa/asoundlib.h> // IWYU pragma: export
 
 #if defined(SND_LIB_VERSION)
   #if __has_include(<alsa/rawmidi.h>) && SND_LIB_VERSION >= ((1 << 16) | (2 << 8) | 6)
@@ -241,6 +241,7 @@ struct libasound
       LIBREMIDI_SYMBOL_INIT(snd_seq, client_id)
       LIBREMIDI_SYMBOL_INIT(snd_seq, client_info_get_client)
       LIBREMIDI_SYMBOL_INIT(snd_seq, client_info_get_name)
+      LIBREMIDI_SYMBOL_INIT(snd_seq, client_info_get_card)
       LIBREMIDI_SYMBOL_INIT(snd_seq, client_info_set_client)
       LIBREMIDI_SYMBOL_INIT(snd_seq, client_info_sizeof)
       LIBREMIDI_SYMBOL_INIT(snd_seq, close)
@@ -298,6 +299,7 @@ struct libasound
     LIBREMIDI_SYMBOL_DEF(snd_seq, client_id)
     LIBREMIDI_SYMBOL_DEF(snd_seq, client_info_get_client)
     LIBREMIDI_SYMBOL_DEF(snd_seq, client_info_get_name)
+    LIBREMIDI_SYMBOL_DEF(snd_seq, client_info_get_card)
     LIBREMIDI_SYMBOL_DEF(snd_seq, client_info_set_client)
     LIBREMIDI_SYMBOL_DEF(snd_seq, client_info_sizeof)
     LIBREMIDI_SYMBOL_DEF(snd_seq, close)
