@@ -120,27 +120,13 @@ change in the future, however any path emitted will always be a valid Win32 path
 */
 #ifdef _WIN32
 LLFIO_HEADERS_ONLY_FUNC_SPEC result<filesystem::path> to_win32_path(const fs_handle &h, win32_path_namespace mapping = win32_path_namespace::any) noexcept;
-LLFIO_TEMPLATE(class T)
-LLFIO_TREQUIRES(LLFIO_TPRED(!std::is_base_of<fs_handle, T>::value && std::is_base_of<handle, T>::value))
-inline result<filesystem::path> to_win32_path(const T &h, win32_path_namespace mapping = win32_path_namespace::any) noexcept
-{
-  struct wrapper final : public fs_handle
-  {
-    const handle &_h;
-    explicit wrapper(const handle &h)
-        : _h(h)
-    {
-    }
-    virtual const handle &_get_handle() const noexcept override { return _h; }
-  } _(h);
-  return to_win32_path(_, mapping);
-}
 #else
 inline result<filesystem::path> to_win32_path(const fs_handle &h, win32_path_namespace mapping = win32_path_namespace::any) noexcept;
 LLFIO_TEMPLATE(class T)
 LLFIO_TREQUIRES(LLFIO_TPRED(!std::is_base_of<fs_handle, T>::value && std::is_base_of<handle, T>::value))
-inline result<filesystem::path> to_win32_path(const T &h, win32_path_namespace /*unused*/ = win32_path_namespace::any) noexcept
+inline result<filesystem::path> to_win32_path(const T &h, win32_path_namespace mapping = win32_path_namespace::any) noexcept
 {
+  (void) mapping;
   return h.current_path();
 }
 #endif
@@ -153,9 +139,13 @@ inline result<filesystem::path> to_win32_path(const T &h, win32_path_namespace /
 class LLFIO_DECL fs_handle
 {
 #ifdef _WIN32
-  friend LLFIO_HEADERS_ONLY_FUNC_SPEC result<filesystem::path> to_win32_path(const fs_handle &h, win32_path_namespace mapping) noexcept;
+  friend result<filesystem::path> to_win32_path(const fs_handle &h, win32_path_namespace mapping) noexcept;
 #else
-  friend inline result<filesystem::path> to_win32_path(const fs_handle &h, win32_path_namespace /*unused*/) noexcept { return h._get_handle().current_path(); }
+  friend inline result<filesystem::path> to_win32_path(const fs_handle &h, win32_path_namespace mapping) noexcept
+  {
+    (void) mapping;
+    return h._get_handle().current_path();
+  }
 #endif
 
 public:
@@ -177,6 +167,8 @@ protected:
 
   virtual const handle &_get_handle() const noexcept = 0;
 
+  virtual result<void> _replace_handle(handle &&o) noexcept = 0;
+
 protected:
   //! Default constructor
   constexpr fs_handle() {}  // NOLINT
@@ -496,6 +488,25 @@ public:
 #endif
 };
 
+#ifdef _WIN32
+LLFIO_TEMPLATE(class T)
+LLFIO_TREQUIRES(LLFIO_TPRED(!std::is_base_of<fs_handle, T>::value && std::is_base_of<handle, T>::value))
+inline result<filesystem::path> to_win32_path(const T &h, win32_path_namespace mapping = win32_path_namespace::any) noexcept
+{
+  struct wrapper final : public fs_handle
+  {
+    const handle &_h;
+    explicit wrapper(const handle &h)
+        : _h(h)
+    {
+    }
+    virtual const handle &_get_handle() const noexcept override { return _h; }
+  } _(h);
+  return to_win32_path(_, mapping);
+}
+#endif
+
+
 namespace detail
 {
   LLFIO_HEADERS_ONLY_FUNC_SPEC result<path_handle> containing_directory(optional<std::reference_wrapper<filesystem::path>> out_filename, const handle &h,
