@@ -7,10 +7,11 @@ source ci/common.setup.sh
 # removing busybox-which removes git
 source ci/common.deps.sh
 
-$SUDO zypper -n remove busybox-which
+# $SUDO zypper -n remove busybox-which
 $SUDO zypper -n install \
    git \
    cmake ninja gcc gcc-c++ \
+   libquadmath-devel \
    llvm-devel \
    libjack-devel alsa-devel \
    portaudio-devel \
@@ -26,5 +27,6 @@ $SUDO zypper -n install \
    qt6-shadertools-devel qt6-shadertools-private-devel \
    qt6-websockets-devel qt6-serialport-devel  \
    qt6-qml-devel qt6-qml-private-devel \
-   ffmpeg-5-libavcodec-devel ffmpeg-5-libavdevice-devel ffmpeg-5-libavfilter-devel ffmpeg-5-libavformat-devel ffmpeg-5-libswresample-devel
+   ffmpeg-7-libavcodec-devel ffmpeg-7-libavdevice-devel ffmpeg-7-libavfilter-devel ffmpeg-7-libavformat-devel ffmpeg-7-libswresample-devel \
+   zlib-devel zlib-devel-static
 
