@@ -61,6 +61,7 @@ printf "r%s.%s" "$(git rev-list --count HEAD)" "$(git rev-parse --short HEAD)" >
   rm -rf 3rdparty/quickcpplib/doc
   rm -rf 3rdparty/quickcpplib/pcpp
   rm -rf 3rdparty/shmdata/doc
+  rm -rf 3rdparty/sh4lt/doc
   rm -rf 3rdparty/snappy/third_party
   rm -rf 3rdparty/snappy/testdata
   rm -rf 3rdparty/DSPFilters/DSPFiltersDemo
@@ -79,10 +80,14 @@ printf "r%s.%s" "$(git rev-list --count HEAD)" "$(git rev-parse --short HEAD)" >
   find . -name '*.user.*' -exec rm {} \;
 )
 
-tar caf ossia-score.tar.xz --transform "s,^\.\/,ossia-score-$GITTAGNOV/," ./*
-gpg --import $PUBKEY_SECUREFILEPATH
-gpg --allow-secret-key-import --import $PRIVKEY_SECUREFILEPATH
-gpg -ab ossia-score.tar.xz
+if [[ -v GPG_SIGN_PUBKEY ]]; then
+  export PUBKEY_SECUREFILEPATH=gpg.pub.asc
+  export PRIVKEY_SECUREFILEPATH=gpg.priv.asc
+  echo "$GPG_SIGN_PUBKEY" > "$PUBKEY_SECUREFILEPATH"
+  echo "$GPG_SIGN_PRIVKEY" > "$PRIVKEY_SECUREFILEPATH"
+fi
 
-pwd
-ls
+tar caf ossia-score.tar.xz --transform "s,^\.\/,ossia-score-$GITTAGNOV/," ./*
+gpg --import "$PUBKEY_SECUREFILEPATH"
+gpg --allow-secret-key-import --import "$PRIVKEY_SECUREFILEPATH"
+gpg -ab ossia-score.tar.xz
