@@ -11,7 +11,7 @@ cmake -GNinja -S "$PWD" -B build \
   -DCMAKE_UNITY_BUILD=1 \
   -DOSSIA_STATIC_EXPORT=1 \
   -DSCORE_INSTALL_HEADERS=1 \
-  -DKFR_ARCH=sse2 \
+  -DKFR_ARCH=avx2 \
   -DSCORE_DEPLOYMENT_BUILD=1 \
   -DCMAKE_C_FLAGS="-g0" \
   -DCMAKE_CXX_FLAGS="-g0"
