@@ -1,12 +1,14 @@
 #pragma once
 
 #include <Engine/Node/CommonWidgets.hpp>
+
+#include <ossia/network/value/value.hpp>
+
 #include <halp/audio.hpp>
 #include <halp/controls.hpp>
 #include <halp/meta.hpp>
 
-
-namespace Example
+namespace spat
 {
 
 class MultiCursorManager
@@ -17,10 +19,9 @@ public:
   halp_meta(category, "Control/Spatialization")
   halp_meta(description, "Can generate a position table")
   halp_meta(manual_url, "https://ossia.io/score-docs/processes/multicursor.html")
-  halp_meta(author, "Ahmed El Moudden")
+  halp_meta(author, "Ahmed El Moudden, Société des Arts Technologiques")
   halp_meta(uuid, "20f771a1-0e9a-4db2-bb7c-011467d84ded")
 
-
   struct ins
   {
     struct
