@@ -1,5 +1,6 @@
 #pragma once
 #include <boost/container/vector.hpp>
+#include <boost/dynamic_bitset.hpp>
 
 #include <QDebug>
 #include <QImage>
@@ -21,7 +22,7 @@ struct FloatTensor
   Ort::Value value;
 };
 
-inline FloatTensor tensorFromARGB(
+inline FloatTensor nchw_tensorFromARGB(
     ModelSpec::Port& port,
     const unsigned char* source_bits,
     int source_w,
@@ -29,21 +30,20 @@ inline FloatTensor tensorFromARGB(
     int model_w,
     int model_h,
     boost::container::vector<float>& input_tensor_values,
-    bool normalize_resnet = false)
+    std::array<float, 3> mean,
+    std::array<float, 3> std)
 {
   auto& input_shape = port.shape;
   QImage img = QImage(source_bits, source_w, source_h, QImage::Format_ARGB32);
-  img = img.scaled(
+  img = std::move(img).scaled(
       model_w,
       model_h,
       Qt::AspectRatioMode::KeepAspectRatioByExpanding,
       Qt::SmoothTransformation);
-  if (model_w != img.width() || model_h != img.width())
+  if (model_w != img.width() || model_h != img.height())
     img = img.copy(0, 0, model_w, model_h);
-  img = img.rgbSwapped();
-  img = img.convertToFormat(QImage::Format_RGB888);
+  img = std::move(img).convertToFormat(QImage::Format_RGB888);
 
-  // FIXME pass storage as input instead
   input_tensor_values.resize(
       3 * model_w * model_h, boost::container::default_init);
 
@@ -52,32 +52,17 @@ inline FloatTensor tensorFromARGB(
   auto dst_r = dst;
   auto dst_g = dst_r + model_w * model_h;
   auto dst_b = dst_g + model_w * model_h;
-  if (normalize_resnet)
-  {
-    nhwc_to_nchw<float>(
-        model_w,
-        model_h,
-        3 * model_w,
-        ptr,
-        dst_r,
-        dst_g,
-        dst_b,
-        {255.f * 0.485f, 255.f * 0.456f, 255.f * 0.406f},
-        {255.f * 0.229f, 255.f * 0.224f, 255.f * 0.225f});
-  }
-  else
-  {
-    nhwc_to_nchw<float>(
-        model_w,
-        model_h,
-        3 * model_w,
-        ptr,
-        dst_r,
-        dst_g,
-        dst_b,
-        {0., 0., 0.},
-        {255., 255., 255.});
-  }
+
+  nhwc_to_nchw<float>(
+      model_w,
+      model_h,
+      img.bytesPerLine(),
+      ptr,
+      dst_r,
+      dst_g,
+      dst_b,
+      mean,
+      std);
 
   FloatTensor f{
       .storage = {},
@@ -87,7 +72,7 @@ inline FloatTensor tensorFromARGB(
 }
 
 // When coming from a GL_RGBA texture
-inline FloatTensor tensorFromRGBA(
+inline FloatTensor nchw_tensorFromRGBA(
     ModelSpec::Port& port,
     const unsigned char* source_bits,
     int source_w,
@@ -95,7 +80,8 @@ inline FloatTensor tensorFromRGBA(
     int model_w,
     int model_h,
     boost::container::vector<float>& input_tensor_values,
-    bool normalize_resnet = false)
+    std::array<float, 3> mean,
+    std::array<float, 3> std)
 {
   auto& input_shape = port.shape;
   QImage img
@@ -105,9 +91,9 @@ inline FloatTensor tensorFromRGBA(
       model_h,
       Qt::AspectRatioMode::KeepAspectRatioByExpanding,
       Qt::SmoothTransformation);
-  if (model_w != img.width() || model_h != img.width())
+  if (model_w != img.width() || model_h != img.height())
     img = img.copy(0, 0, model_w, model_h);
-  img = img.convertToFormat(QImage::Format_RGB888);
+  img = std::move(img).convertToFormat(QImage::Format_RGB888);
 
   // FIXME pass storage as input instead
   input_tensor_values.resize(
@@ -118,32 +104,16 @@ inline FloatTensor tensorFromRGBA(
   auto dst_r = dst;
   auto dst_g = dst_r + model_w * model_h;
   auto dst_b = dst_g + model_w * model_h;
-  if (normalize_resnet)
-  {
-    nhwc_to_nchw<float>(
-        model_w,
-        model_h,
-        3 * model_w,
-        ptr,
-        dst_r,
-        dst_g,
-        dst_b,
-        {255.f * 0.485f, 255.f * 0.456f, 255.f * 0.406f},
-        {255.f * 0.229f, 255.f * 0.224f, 255.f * 0.225f});
-  }
-  else
-  {
-    nhwc_to_nchw<float>(
-        model_w,
-        model_h,
-        3 * model_w,
-        ptr,
-        dst_r,
-        dst_g,
-        dst_b,
-        {0., 0., 0.},
-        {255., 255., 255.});
-  }
+  nhwc_to_nchw<float>(
+      model_w,
+      model_h,
+      img.bytesPerLine(),
+      ptr,
+      dst_r,
+      dst_g,
+      dst_b,
+      mean,
+      std);
 
   FloatTensor f{
       .storage = {},
@@ -170,13 +140,13 @@ inline FloatTensor nhwc_rgb_tensorFromRGBA(
       model_h,
       Qt::AspectRatioMode::KeepAspectRatioByExpanding,
       Qt::SmoothTransformation);
-  if (model_w != img.width() || model_h != img.width())
+  if (model_w != img.width() || model_h != img.height())
     img = img.copy(0, 0, model_w, model_h);
 
-  // FIXME pass storage as input instead
   input_tensor_values.resize(
       3 * model_w * model_h, boost::container::default_init);
 
+  // FIXME does not work if img.bytesPerLine() != 4 * model_w;
   auto ptr = (unsigned char*)img.constBits();
   auto dst = input_tensor_values.data();
   for (int src_i = 0, dst_i = 0; src_i < 3 * model_w * model_h;)
@@ -228,6 +198,73 @@ inline QImage drawRects(const unsigned char* input, int w, int h, auto& rects)
   return img;
 }
 
+// Function to draw segmentation results on a QImage
+inline QImage drawBlobAndSegmentation(
+    const unsigned char* input,
+    int w,
+    int h,
+    const auto& segmentations)
+{
+  QImage img(input, w, h, QImage::Format_RGBA8888);
+  QImage maskOverlay(w, h, QImage::Format_ARGB32_Premultiplied);
+  maskOverlay.fill(Qt::transparent);
+
+  QPainter painter(&maskOverlay);
+  painter.setRenderHint(QPainter::Antialiasing);
+
+  int k = 120;
+  for (const auto& seg : segmentations)
+  {
+    QColor color = QColor::fromHsv(k, 200, 220);
+    color.setAlpha(100);
+    auto r = color.red();
+    auto g = color.green();
+    auto b = color.blue();
+    painter.setBrush(color);
+    painter.setPen(color);
+    auto data = img.bits();
+    const boost::dynamic_bitset<>& mask = seg.mask;
+#pragma omp simd
+    for (int y = 0; y < h; y++)
+    {
+      for (int x = 0; x < w; x++)
+      {
+        if (mask[y * w + x])
+        {
+          auto* pixel = data + (y * w + x) * 4;
+          pixel[0] = std::min(pixel[0] + r * 0.25, 255.);
+          pixel[1] = std::min(pixel[1] + g * 0.25, 255.);
+          pixel[2] = std::min(pixel[2] + b * 0.25, 255.);
+        }
+      }
+    }
+
+    k += 3759;
+    k = k % 359;
+  }
+
+  QPainter finalPainter(&img);
+  finalPainter.drawImage(0, 0, maskOverlay);
+
+  for (const auto& seg : segmentations)
+  {
+    finalPainter.setBrush(Qt::NoBrush);
+    finalPainter.setPen(QPen(Qt::white, 2));
+    finalPainter.drawRect(
+        seg.geometry.x, seg.geometry.y, seg.geometry.w, seg.geometry.h);
+
+    QString label = QString("%1: %2")
+                        .arg(QString::fromStdString(seg.name))
+                        .arg(seg.confidence, 0, 'f', 2);
+
+    QPointF textPos(seg.geometry.x, seg.geometry.y - 5);
+    finalPainter.setPen(Qt::white);
+    finalPainter.drawText(textPos, label);
+  }
+
+  return img;
+}
+
 inline QImage drawKeypoints(
     const unsigned char* input,
     int w,
@@ -243,6 +280,7 @@ inline QImage drawKeypoints(
     p.setBrush(Qt::NoBrush);
     for (const auto& kp : keypoints)
     {
+      p.setPen(QPen(QColor::fromRgbF(1., 1., 1., kp.confidence()), 4));
       //if (kp.confidence() >= min_confidence)
         p.drawEllipse(QPoint(kp.x, kp.y), 5, 5);
     }
