@@ -31,7 +31,7 @@ void ResnetDetector::operator()()
   }
   auto& ctx = *this->ctx;
   auto spec = ctx.readModelSpec();
-  auto t = tensorFromARGB(
+  auto t = nchw_tensorFromARGB(
       spec.inputs[0],
       in_tex.bytes,
       in_tex.width,
@@ -39,7 +39,8 @@ void ResnetDetector::operator()()
       this->inputs.resolution.value.x,
       this->inputs.resolution.value.y,
       storage,
-      true);
+      {255.f * 0.485f, 255.f * 0.456f, 255.f * 0.406f},
+      {255.f * 0.229f, 255.f * 0.224f, 255.f * 0.225f});
   Ort::Value tt[1] = {std::move(t.value)};
 
   assert(1 == spec.output_names_char.size());
