@@ -38,11 +38,18 @@
 #include <QUrl>
 #include <qconfig.h>
 #include <qobjectdefs.h>
+
 #if defined(QT_FEATURE_thread)
 #if QT_FEATURE_thread == 1
 #include <QThreadPool>
 #endif
 #endif
+
+#include <score/gfx/Vulkan.hpp>
+#if QT_HAS_VULKAN && __has_include(<QVulkanInstance>)
+#include <QVulkanInstance>
+#endif
+
 #include <spdlog/sinks/stdout_sinks.h>
 #include <spdlog/spdlog.h>
 
@@ -125,9 +132,7 @@ static void setQApplicationSettings(QApplication& m_app)
   // Sadly Qt asserts so wh have to simulate the loading of a plugin (see above).
   // For older Qts we won't be debugging anyways and will be linking against distro Qt versions so we just set the style
   // manually
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0) || QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
   m_app.setStyle(new PhantomStyle);
-#endif
 
   auto pal = qApp->palette();
   pal.setBrush(QPalette::Window, QColor("#222222"));        //#1A2024"));
@@ -151,7 +156,7 @@ static void setQApplicationSettings(QApplication& m_app)
   //  pal.setBrush(QPalette::Dark, QColor("#808080"));
   // pal.setBrush(QPalette::Shadow, QColor("#666666"));
 
-#if defined(__APPLE__) && QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#if defined(__APPLE__)
   constexpr const double defaultFontSize = 10. * 96. / 72.;
 #else
   constexpr const double defaultFontSize = 10.;
@@ -186,7 +191,8 @@ bool runningUnderAnUISession() noexcept
     return true;
   if(qgetenv("XDG_SESSION_TYPE") != "tty")
     return true;
-  if(platform.contains("gl"))
+  if(platform.contains("gl") || platform.contains("vkkhr")
+     || platform.contains("linuxfb") || platform.contains("vnc"))
     return true;
   return false;
 #endif
@@ -287,6 +293,13 @@ Application::~Application()
   svc.taskpool.reset();
   svc.threadpool.reset();
 
+#if QT_HAS_VULKAN
+  if(auto vk = score::gfx::staticVulkanInstance(false))
+  {
+    delete vk;
+  }
+
+#endif
   delete m_app;
 }
 
@@ -311,7 +324,7 @@ void Application::init()
     }
     else
     {
-#if !defined(__arm__)
+#if !((defined(__arm__) || defined(__aarch64__)))
       QOpenGLContext ctx;
       appSettings.opengl = ctx.create() && ctx.format().majorVersion() > 1;
 #else
