@@ -28,6 +28,8 @@ extern "C" void sincos(double x, double* sin, double* cos)
   *cos = std::cos(x);
 }
 #endif
+
+#include <winrt/Windows.Foundation.h>
 #endif
 // clang-format on
 
@@ -96,6 +98,12 @@ static struct
 #include <pmmintrin.h>
 #endif
 
+#if defined(__has_feature)
+#if __has_feature(address_sanitizer) && !defined(__SANITIZE_ADDRESS__)
+#define __SANITIZE_ADDRESS__ 1
+#endif
+#endif
+
 #if defined(__APPLE__)
 struct NSAutoreleasePool;
 
@@ -116,7 +124,7 @@ void disableAppRestore()
 void ensureDyldPath()
 {
   auto e = qEnvironmentVariable("DYLD_LIBRARY_PATH");
-  if(e.isEmpty())
+  if(e.isEmpty() || e == "/usr/lib/system/introspection")
   {
     return;
   }
@@ -130,7 +138,7 @@ void ensureDyldPath()
         "uncheck the 'Add library search path to DYLD_LIBRARY_PATH and "
         "DYLD_FRAMEWORK_PATH'\n"
         "checkbox on the execution tab.\n\n"
-        "Current DYLD_LIBRARY_PATH: %s",
+        "Current DYLD_LIBRARY_PATH: '%s'\n",
         e.toStdString().c_str());
 
     // If you see this comment, you are allowed to remove it on your dev
@@ -237,17 +245,10 @@ static void setup_suil()
   // nrelative to the executable
   if(qEnvironmentVariableIsEmpty("SUIL_MODULE_DIR"))
   {
-    auto path = ossia::get_exe_path();
-    auto last_slash =
-#if defined(_WIN32)
-        path.find_last_of('\\');
-#else
-        path.find_last_of('/');
-#endif
-    if(last_slash == std::string::npos)
+    auto path = ossia::get_exe_folder();
+    if(path.empty())
       return;
 
-    path = path.substr(0, last_slash);
     if(path.ends_with("/bin"))
       path.resize(path.size() - 3);
 
@@ -389,18 +390,10 @@ static void setup_faust_path()
   if(!qEnvironmentVariableIsEmpty("FAUST_LIB_PATH"))
     return;
 
-  auto path = ossia::get_exe_path();
-  auto last_slash =
-#if defined(_WIN32)
-      path.find_last_of('\\');
-#else
-      path.find_last_of('/');
-#endif
-  if(last_slash == std::string::npos)
+  auto path = ossia::get_exe_folder();
+  if(path.empty())
     return;
 
-  path = path.substr(0, last_slash);
-
 #if defined(SCORE_DEPLOYMENT_BUILD)
 #if defined(__APPLE__)
   path += "/../Resources/Faust";
@@ -413,7 +406,8 @@ static void setup_faust_path()
   path += "/src/plugins/score-plugin-faust/faustlibs-prefix/src/faustlibs";
 #endif
 
-  qputenv("FAUST_LIB_PATH", path.c_str());
+  if(QFileInfo{QString::fromUtf8(path)}.isDir())
+    qputenv("FAUST_LIB_PATH", path.c_str());
 }
 
 static void setup_opengl(bool& enable_opengl_ui)
@@ -534,7 +528,6 @@ static void setup_locale()
 
 static void setup_app_flags()
 {
-  qputenv("QT_NO_GLIB", "1");
   qputenv("QSG_USE_SIMPLE_ANIMATION_DRIVER", "1");
   qputenv("QSG_RENDER_LOOP", "basic");
   // Consistency in looks across macOS, Windows (which prevents the horrible 125% scaling) and Linux
@@ -558,6 +551,7 @@ static void setup_app_flags()
 #if defined(__linux__)
   // Else things look horrible on KDE plasma, etc
   qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", "1");
+  // qputenv("QT_NO_GLIB", "1"); // looks like it actually prevents the app from starting on GNOME
 
   if(!qEnvironmentVariableIsSet("FLATPAK_ID"))
   {
@@ -610,8 +604,23 @@ static void setup_limits()
   }
 #endif
 }
+
 namespace
 {
+static void setup_qml()
+{
+#if defined(__SANITIZE_ADDRESS__)
+  if(!qEnvironmentVariableIsSet("QV4_FORCE_INTERPRETER"))
+    qputenv("QV4_FORCE_INTERPRETER", "1");
+  if(!qEnvironmentVariableIsSet("QV4_MM_AGGRESSIVE_GC"))
+    qputenv("QV4_MM_AGGRESSIVE_GC", "1");
+#endif
+  if(!qEnvironmentVariableIsSet("QV4_JS_MAX_STACK_SIZE"))
+    qputenv("QV4_JS_MAX_STACK_SIZE", "16777216");
+  if(!qEnvironmentVariableIsSet("QV4_GC_MAX_STACK_SIZE"))
+    qputenv("QV4_GC_MAX_STACK_SIZE", "16777216");
+}
+
 struct failsafe
 {
   const bool fs = this->read();
@@ -661,6 +670,11 @@ struct failsafe
 
 int main(int argc, char** argv)
 {
+#if defined(_WIN32)
+  winrt::uninit_apartment();
+  winrt::init_apartment(winrt::apartment_type::single_threaded);
+#endif
+
   struct failsafe failsafe;
 
 #if defined(__APPLE__)
@@ -679,10 +693,16 @@ int main(int argc, char** argv)
   setup_locale();
   setup_app_flags();
   setup_fftw();
+  setup_qml();
 
   QPixmapCache::setCacheLimit(819200);
   Application app(argc, argv);
 
+#if defined(_WIN32)
+  winrt::uninit_apartment();
+  winrt::init_apartment(winrt::apartment_type::single_threaded);
+#endif
+
   setup_gdk();
 
 #if defined(__APPLE__)
