@@ -5,8 +5,11 @@
 #include <Device/Address/AddressSettings.hpp>
 #include <Device/Node/DeviceNode.hpp>
 
+#include <score/application/ApplicationContext.hpp>
 #include <score/tools/std/String.hpp>
 
+#include <core/application/ApplicationSettings.hpp>
+
 #include <ossia/detail/logger.hpp>
 #include <ossia/network/base/device.hpp>
 #include <ossia/network/base/parameter.hpp>
@@ -17,7 +20,7 @@
 #include <ossia-qt/invoke.hpp>
 #include <ossia-qt/name_utils.hpp>
 
-#include <boost/asio/io_service.hpp>
+#include <boost/asio/io_context.hpp>
 #include <boost/asio/post.hpp>
 #include <boost/asio/strand.hpp>
 #include <boost/asio/use_future.hpp>
@@ -387,8 +390,6 @@ void DeviceInterface::updateSettings(const Device::DeviceSettings& newsettings)
 
     m_settings = newsettings;
 
-    reconnect();
-
     auto con_handle = std::make_shared<QMetaObject::Connection>();
     *con_handle = connect(
         this, &Device::DeviceInterface::deviceChanged, this,
@@ -399,6 +400,8 @@ void DeviceInterface::updateSettings(const Device::DeviceSettings& newsettings)
         QObject::disconnect(*con_handle);
       }
         });
+
+    reconnect();
   }
   else
   {
@@ -797,6 +800,9 @@ Device::Node DeviceInterface::getNodeWithoutChildren(const State::Address& addre
 
 void DeviceInterface::setListening(const State::Address& addr, bool b)
 {
+  static const bool gui = score::AppContext().applicationSettings.gui;
+  if(!gui)
+    return;
   if(auto dev = getDevice())
   {
     // First check if the address is already listening
@@ -861,6 +867,10 @@ std::vector<State::Address> DeviceInterface::listening() const
   if(!connected())
     return {};
 
+  static const bool gui = score::AppContext().applicationSettings.gui;
+  if(!gui)
+    return {};
+
   std::vector<State::Address> addrs;
   addrs.reserve(m_callbacks.size());
 
@@ -877,6 +887,10 @@ void DeviceInterface::addToListening(const std::vector<State::Address>& addresse
   if(!connected())
     return;
 
+  static const bool gui = score::AppContext().applicationSettings.gui;
+  if(!gui)
+    return;
+
   for(const auto& addr : addresses)
   {
     SCORE_ASSERT(addr.device == this->settings().name);
@@ -937,7 +951,7 @@ void OwningDeviceInterface::releaseDevice()
 {
   DeviceInterface::disconnect();
   deviceChanged(m_dev.get(), nullptr);
-  m_dev.release();
+  // FIXME instead it should just be shared_ptrs in player m_dev.release();
 }
 
 void OwningDeviceInterface::disconnect()
@@ -1026,14 +1040,18 @@ void DeviceInterface::addressRemoved(const ossia::net::parameter_base& addr)
 void releaseDevice(
     ossia::net::network_context& ctx, std::unique_ptr<ossia::net::device_base> dd)
 {
-  if(dd)
+  releaseDevice(ctx, std::shared_ptr(std::move(dd)));
+}
+
+void releaseDevice(
+    ossia::net::network_context& ctx, std::shared_ptr<ossia::net::device_base> shared_dd)
+{
+  if(shared_dd)
   {
-    auto shared_dd = std::shared_ptr(std::move(dd));
     auto strand = boost::asio::make_strand(ctx.context);
     boost::asio::dispatch(strand, [dev = shared_dd] { dev->get_protocol().stop(); });
 
-    std::future<void> wait1
-        = boost::asio::dispatch(strand, boost::asio::use_future);
+    std::future<void> wait1 = boost::asio::dispatch(strand, boost::asio::use_future);
     if(auto res = wait1.wait_for(std::chrono::seconds(1));
        res != std::future_status::ready)
     {
@@ -1042,8 +1060,7 @@ void releaseDevice(
 
     boost::asio::dispatch(strand, [d = std::move(shared_dd)]() mutable { d.reset(); });
 
-    std::future<void> wait2
-        = boost::asio::dispatch(strand, boost::asio::use_future);
+    std::future<void> wait2 = boost::asio::dispatch(strand, boost::asio::use_future);
     if(auto res = wait2.wait_for(std::chrono::seconds(1));
        res != std::future_status::ready)
     {
