@@ -544,6 +544,11 @@ struct SCORE_LIB_PROCESS_EXPORT XYSpinboxes : public Process::ControlInlet
   XYSpinboxes(
       ossia::vec2f min, ossia::vec2f max, ossia::vec2f init, bool integral,
       const QString& name, Id<Process::Port> id, QObject* parent);
+
+  XYSpinboxes(DataStream::Deserializer& vis, QObject* parent);
+  XYSpinboxes(JSONObject::Deserializer& vis, QObject* parent);
+  XYSpinboxes(DataStream::Deserializer&& vis, QObject* parent);
+  XYSpinboxes(JSONObject::Deserializer&& vis, QObject* parent);
   ~XYSpinboxes();
 
   auto getMin() const noexcept { return domain().get().convert_min<ossia::vec2f>(); }
@@ -552,7 +557,7 @@ struct SCORE_LIB_PROCESS_EXPORT XYSpinboxes : public Process::ControlInlet
 
   using Process::ControlInlet::ControlInlet;
 
-  const bool integral{};
+  bool integral{};
 };
 
 struct SCORE_LIB_PROCESS_EXPORT XYZSpinboxes : public Process::ControlInlet
