@@ -42,13 +42,14 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
 
   template <typename Tex>
   void createInput(
-      score::gfx::RenderList& renderer, int k, const Tex& texture_spec, QSize size)
+      score::gfx::RenderList& renderer, int k, const Tex& texture_spec,
+      const score::gfx::RenderTargetSpecs& spec)
   {
     auto port = this->node().input[k];
     static constexpr auto flags
         = QRhiTexture::RenderTarget | QRhiTexture::UsedAsTransferSource;
     auto texture = renderer.state.rhi->newTexture(
-        gpp::qrhi::textureFormat<Tex>(), size, 1, flags);
+        gpp::qrhi::textureFormat<Tex>(), spec.size, 1, flags);
     SCORE_ASSERT(texture->create());
     m_rts[port] = score::gfx::createRenderTarget(
         renderer.state, texture, renderer.samples(), renderer.requiresDepth());
@@ -66,7 +67,7 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
   void loadInputTexture(QRhi& rhi, avnd::cpu_texture auto& cpu_tex, int k)
   {
     auto& buf = m_readbacks[k].data;
-    if(buf.size() != 4 * cpu_tex.width * cpu_tex.height)
+    if(buf.size() != cpu_tex.bytesize())
     {
       cpu_tex.bytes = nullptr;
     }
@@ -74,9 +75,10 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
     {
       cpu_tex.bytes = reinterpret_cast<unsigned char*>(buf.data());
 
-      if(rhi.isYUpInFramebuffer())
+      if(rhi.isYUpInNDC())
         if(cpu_tex.width * cpu_tex.height > 0)
-          inplaceMirror(cpu_tex.bytes, cpu_tex.width, cpu_tex.height);
+          inplaceMirror(
+              cpu_tex.bytes, cpu_tex.width, cpu_tex.height, cpu_tex.bytes_per_pixel);
 
       cpu_tex.changed = true;
     }
@@ -95,20 +97,21 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
     int k = 0;
     avnd::cpu_texture_input_introspection<Node_T>::for_all(
         avnd::get_inputs<Node_T>(state), [&]<typename F>(F& t) {
-      QSize sz = renderer.state.renderSize;
+      // FIXME k isn't the port index, it's the texture port index
+      auto spec = this->node().resolveRenderTargetSpecs(k, renderer);
       if constexpr(requires {
                      t.request_width;
                      t.request_height;
                    })
       {
-        sz.rwidth() = t.request_width;
-        sz.rheight() = t.request_height;
+        spec.size.rwidth() = t.request_width;
+        spec.size.rheight() = t.request_height;
       }
-      createInput(renderer, k, t.texture, sz);
+      createInput(renderer, k, t.texture, spec);
       if constexpr(avnd::cpu_fixed_format_texture<decltype(t.texture)>)
       {
-        t.texture.width = sz.width();
-        t.texture.height = sz.height();
+        t.texture.width = spec.size.width();
+        t.texture.height = spec.size.height();
       }
       k++;
     });
@@ -231,9 +234,9 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
   void postprocess_geometry(Field& ctrl)
   {
     using namespace avnd;
-    bool mesh_dirty{};
-    bool tform_dirty{};
-    mesh_dirty = ctrl.dirty_mesh;
+    // bool mesh_dirty{};
+    // bool tform_dirty{};
+    // mesh_dirty = ctrl.dirty_mesh;
 
     if(ctrl.dirty_mesh)
     {
