@@ -32,7 +32,11 @@ out gl_PerVertex { vec4 gl_Position; };
 
 void main()
 {
+#if defined(QSHADER_SPIRV) || defined(QSHADER_GLSL)
+  v_texcoord = vec2(texcoord.x, 1. - texcoord.y);
+#else
   v_texcoord = texcoord;
+#endif
   gl_Position = renderer.clipSpaceCorrMatrix * vec4(position.xy, 0.0, 1.);
 }
 )_";
@@ -48,7 +52,6 @@ vec2 renderSize;
 
 layout(binding=3) uniform sampler2D y_tex;
 
-
 void main ()
 {
   fragColor = texture(y_tex, v_texcoord);
