@@ -3,6 +3,7 @@
 #include "sajson.h"
 
 #include <ossia/detail/flat_set.hpp>
+#include <ossia/detail/string_map.hpp>
 
 #include <boost/algorithm/string.hpp>
 #include <boost/regex.hpp>
@@ -421,8 +422,8 @@ input parse(const sajson::value& v)
 
 using root_fun = void (*)(descriptor&, const sajson::value&);
 using input_fun = input (*)(const sajson::value&);
-static const std::unordered_map<std::string, root_fun>& root_parse{[] {
-  static std::unordered_map<std::string, root_fun> p;
+static const ossia::string_map<root_fun>& root_parse{[] {
+  static ossia::string_map<root_fun> p;
   p.insert({"DESCRIPTION", [](descriptor& d, const sajson::value& v) {
               if(v.get_type() == sajson::TYPE_STRING)
                 d.description = v.as_string();
@@ -443,8 +444,8 @@ static const std::unordered_map<std::string, root_fun>& root_parse{[] {
               }
             }});
 
-  static const std::unordered_map<std::string, input_fun>& input_parse{[] {
-    static std::unordered_map<std::string, input_fun> i;
+  static const ossia::hash_map<std::string, input_fun>& input_parse{[] {
+    static ossia::hash_map<std::string, input_fun> i;
     i.insert({"float", [](const auto& s) { return parse<float_input>(s); }});
     i.insert({"long", [](const auto& s) { return parse<long_input>(s); }});
     i.insert({"bool", [](const auto& s) { return parse<bool_input>(s); }});
