@@ -38,9 +38,9 @@ struct float_input
 {
   using value_type = double;
   using has_minmax = std::true_type;
-  double min{};
-  double max{};
-  double def{};
+  double min{0.};
+  double max{1.};
+  double def{0.5};
 };
 
 struct point2d_input
@@ -101,6 +101,7 @@ struct pass
   std::string target;
   bool persistent{};
   bool float_storage{};
+  bool nearest_filter{};
   std::string width_expression{};
   std::string height_expression{};
 };
@@ -147,13 +148,12 @@ public:
   std::string vertex() const;
   std::string fragment() const;
   std::string geometry_filter() const;
+  static std::pair<int, descriptor> parse_isf_header(std::string_view source);
 
 private:
   void parse_isf();
   void parse_shadertoy();
   void parse_glsl_sandbox();
   void parse_geometry_filter();
-
-  std::string parse_isf_header(std::string_view source);
 };
 }
