@@ -6,6 +6,8 @@
 
 #include <JS/Qml/QtMetatypes.hpp>
 
+#include <libremidi/detail/conversion.hpp>
+
 #if defined(SCORE_HAS_GPU_JS)
 #include <Gfx/TexturePort.hpp>
 
@@ -17,6 +19,7 @@
 #include <ossia/detail/math.hpp>
 #include <ossia/detail/ssize.hpp>
 #include <ossia/network/domain/domain.hpp>
+
 #include <ossia-qt/js_utilities.hpp>
 
 #include <QJSValue>
@@ -26,6 +29,7 @@
 #include <QVector>
 
 #include <libremidi/message.hpp>
+#include <libremidi/ump.hpp>
 
 #include <score_plugin_js_export.h>
 #include <wobjectimpl.h>
@@ -324,6 +328,39 @@ public:
   W_INLINE_PROPERTY_CREF(QStringList, choices, {}, choices, setChoices, choicesChanged)
 };
 
+class SCORE_PLUGIN_JS_EXPORT ComboBox : public ControlInlet
+{
+  W_OBJECT(ComboBox)
+
+public:
+  using ControlInlet::ControlInlet;
+  virtual ~ComboBox() override;
+  bool isEvent() const override { return true; }
+
+  Process::Inlet* make(Id<Process::Port>&& id, QObject* parent) override
+  {
+    std::vector<std::pair<QString, ossia::value>> choices;
+    choices.reserve(m_choices.size());
+    for(auto& c : m_choices)
+      choices.emplace_back(c, c.toStdString());
+    return new Process::ComboBox{choices, current(), objectName(), id, parent};
+  }
+
+  auto getValues() const { return choices(); }
+
+  std::string current() const
+  {
+    if(!m_choices.isEmpty() && ossia::valid_index(m_index, m_choices))
+    {
+      return m_choices[m_index].toStdString();
+    }
+    return {};
+  }
+
+  W_INLINE_PROPERTY_VALUE(int, index, {}, index, setIndex, indexChanged)
+  W_INLINE_PROPERTY_CREF(QStringList, choices, {}, choices, setChoices, choicesChanged)
+};
+
 class SCORE_PLUGIN_JS_EXPORT Toggle : public ControlInlet
 {
   W_OBJECT(Toggle)
@@ -490,14 +527,15 @@ public:
   void setMidi(const T& arr)
   {
     m_midi.clear();
-    for(const libremidi::message& mess : arr)
+    for(const libremidi::ump& mess : arr)
     {
+      auto m1 = libremidi::midi1_from_ump(mess);
       const auto N = mess.size();
       QVector<int> m;
       m.resize(N);
 
       for(std::size_t i = 0; i < N; i++)
-        m[i] = mess.bytes[i];
+        m[i] = m1.bytes[i];
 
       m_midi.push_back(QVariant::fromValue(m));
     }
