@@ -274,7 +274,7 @@ struct RequestOverlayMenuCallback
     using namespace Scenario::Command;
 
     Macro m{new AddProcessInNewSlot, self.context()};
-    if(auto p = m.createProcessInNewSlot(self.model(), key, dat))
+    if(m.createProcessInNewSlot(self.model(), key, dat))
     {
       m.commit();
     }
@@ -858,7 +858,7 @@ void TemporalIntervalPresenter::on_layerModelPutToFront(
       {
         if(ld.model().id() == proc.id())
         {
-          if(auto pres = ld.mainPresenter())
+          if(auto pres = ld.mainPresenter(); bool(pres))
           {
             auto factory
                 = m_context.processList.findDefaultFactory(ld.model().concreteKey());
@@ -1016,7 +1016,7 @@ void TemporalIntervalPresenter::selectedSlot(int i) const
     {
       if(!lay_slot->layers.empty())
       {
-        if(auto pres = lay_slot->layers.front().mainPresenter())
+        if(auto pres = lay_slot->layers.front().mainPresenter(); bool(pres))
         {
           m_context.focusDispatcher.focus(lay_slot->layers.front().mainPresenter());
           disp.select(m_model.processes.at(*proc));
